import { fileURLToPath } from "node:url";
import vue from "@vitejs/plugin-vue";
function getRenderer() {
  return {
    name: "@astrojs/vue",
    clientEntrypoint: "@astrojs/vue/client.js",
    serverEntrypoint: "@astrojs/vue/server.js"
  };
}
function getJsxRenderer() {
  return {
    name: "@astrojs/vue (jsx)",
    clientEntrypoint: "@astrojs/vue/client.js",
    serverEntrypoint: "@astrojs/vue/server.js",
    jsxImportSource: "vue",
    jsxTransformOptions: async () => {
      const jsxPlugin = (await import("@vue/babel-plugin-jsx")).default;
      return {
        plugins: [jsxPlugin]
      };
    }
  };
}
function virtualAppEntrypoint(options) {
  const virtualModuleId = "virtual:@astrojs/vue/app";
  const resolvedVirtualModuleId = "\0" + virtualModuleId;
  let getExports;
  return {
    name: "@astrojs/vue/virtual-app",
    buildStart() {
      if (!getExports) {
        getExports = async (id) => {
          const info = await this.load.call(this, { id });
          return info.exports ?? [];
        };
      }
    },
    configureServer(server) {
      if (!getExports) {
        getExports = async (id) => {
          const mod = await server.ssrLoadModule(id);
          return Object.keys(mod) ?? [];
        };
      }
    },
    resolveId(id) {
      if (id == virtualModuleId) {
        return resolvedVirtualModuleId;
      }
    },
    async load(id) {
      const noop = `export const setup = (app) => app;`;
      if (id === resolvedVirtualModuleId) {
        if (options.appEntrypoint) {
          try {
            let resolved;
            if (options.appEntrypoint.startsWith(".")) {
              resolved = await this.resolve(
                fileURLToPath(new URL(options.appEntrypoint, options.root))
              );
            } else {
              resolved = await this.resolve(options.appEntrypoint, fileURLToPath(options.root));
            }
            if (!resolved) {
              throw new Error("Unable to resolve appEntrypoint");
            }
            const exports = await getExports(resolved.id);
            if (!exports.includes("default")) {
              options.logger.warn(
                `appEntrypoint \`${options.appEntrypoint}\` does not export a default function. Check out https://docs.astro.build/en/guides/integrations-guide/vue/#appentrypoint.`
              );
              return noop;
            }
            return `export { default as setup } from "${resolved.id}";`;
          } catch {
            options.logger.warn(
              `Unable to resolve appEntrypoint \`${options.appEntrypoint}\`. Does the file exist?`
            );
          }
        }
        return noop;
      }
    }
  };
}
async function getViteConfiguration(options) {
  const config = {
    optimizeDeps: {
      include: ["@astrojs/vue/client.js", "vue"],
      exclude: ["@astrojs/vue/server.js", "virtual:@astrojs/vue/app"]
    },
    plugins: [vue(options), virtualAppEntrypoint(options)],
    ssr: {
      external: ["@vue/server-renderer"],
      noExternal: ["vuetify", "vueperslides", "primevue"]
    }
  };
  if (options?.jsx) {
    const vueJsx = (await import("@vitejs/plugin-vue-jsx")).default;
    const jsxOptions = typeof options.jsx === "object" ? options.jsx : void 0;
    config.plugins?.push(vueJsx(jsxOptions));
  }
  return config;
}
function src_default(options) {
  return {
    name: "@astrojs/vue",
    hooks: {
      "astro:config:setup": async ({ addRenderer, updateConfig, config, logger }) => {
        addRenderer(getRenderer());
        if (options?.jsx) {
          addRenderer(getJsxRenderer());
        }
        updateConfig({
          vite: await getViteConfiguration({ ...options, root: config.root, logger })
        });
      }
    }
  };
}
export {
  src_default as default
};
